[retour au README.md](../../../README.md)  
[Retour aux Documents](../../README_DOCUMENTS.md)  
[Retour au diagramme de classes](../README_DIAGRAMMES.md)

# BDD

```plantuml
@startuml
skinparam classAttributeIconSize 0
package MLD{
entity "Athlete" as athlete {
    {static} idAthlete
    username
    nom
    prenom
    email
    sexe
    taille
    poids
    motDePasse
    dateNaissance
    isCoach
}

entity "Amitie" as friendship{
{static}# idAthlete1
{static}# idAthlete2
début
}

entity "Notification" as notif {
    {static} idNotif
    message
    date
    statut
    urgence
    #athleteId
}

entity "Envoi" as sendNotif{
{static}# idAthlete
{static}# idNotif
}

entity "Statistique" as stats {
    {static} idStatistique
    poids
    fcMoyenne
    fcMax
    caloriesBruleesMoy
    date 
    #athleteId
}

entity "Entrainement" as training {
    {static} idEntrainement
    date
    description
    latitude
    longitude
    feedback
    #athleteId
}

entity "Participe" as takepart {
    {static} #athleteId
    {static} #entrainementId   
}

entity "Donne" as givepart {
    {static} #coachId
    {static} #entrainementId   
}


entity "SourceDonnee" as source {
    {static} idSource
    type 
    modele
    precision
    #athleteId
}  

entity "Activite" as activity {
    {static} idActivité
    type
    date
    heureDeDebut
    heureDeFin
    effortRessent
    variabilite
    variance
    ecartType
    moyenne
    maximum
    minimum
    temperatureMoyenne
    #athleteId 
    #sourceId
}
entity "FréquenceCardiaque" as fc {
    {static} idFc
    altitude
    temps : time
    température    
    bpm
    longitude
    latitude
    #activitéId
}

}
activity --> athlete
activity --> source
activity <-- fc
athlete <-- source
stats --> athlete
takepart --> athlete
takepart --> training
givepart --> athlete
givepart --> training
sendNotif --> athlete
sendNotif --> notif
friendship --> athlete
notif --> athlete
athlete <-- friendship
@enduml
```

```plantuml
@startuml

class Athlete {
    idAthlete
    username
    nom
    prenom
    email
    sexe
    taille
    poids
    motDePasse
    dateNaissance
    isCoach
}

class Amitie {
    idAthlete1
    idAthlete2
}

class Notification {
    idNotif
    message
    date
    statut
    urgence
    athleteId
}

class Envoi {
    idAthlete
    idNotif
}

class Statistique {
    idStatistique
    poids
    fcMoyenne
    fcMax
    caloriesBruleesMoy
    date
    athleteId
}

class Entrainement {
    idEntrainement
    date
    description
    latitude
    longitude
    feedback
    athleteId
}

class Participe {
    athleteId
    entrainementId
}

class Donne {
    coachId
    entrainementId
}

class SourceDonnee {
    idSource
    type
    modele
    precision
    athleteId
}

class Activite {
    idActivite
    type
    date
    heureDeDebut
    heureDeFin
    effortRessent
    variabilite
    variance
    ecartType
    moyenne
    maximum
    minimum
    temperatureMoyenne
    athleteId
    sourceId
}

class FrequenceCardiaque {
    idFc
    altitude
    temps
    temperature
    bpm
    longitude
    latitude
    activiteId
}

Athlete "1" --o "0..*" Amitie
Athlete "1" --o "0..*" Notification
Athlete "1" --o "0..*" Statistique
Athlete "1" --o "0..*" Entrainement
Entrainement "0..*" --o "0..*" Athlete : Participants
Entrainement "0..*" --o "0..*" Athlete : Coachs
Athlete "1" --o "0..*" SourceDonnee
Activite "1" --o "0..*" FrequenceCardiaque

@enduml
```