<?php

namespace App\Controller;

use App\Container;
use App\Router\Request\IRequest;
use App\Router\Response\RedirectResponse;
use App\Router\Response\Response;
use App\Router\Response\IResponse;

use App\Router\Session;
use DateInterval;
use DateTime;
use Manager\UserManager;
use Shared\Attributes\Route;
use Shared\Validation;
use Twig\Environment;
use Data\Core\Preferences;
use Shared\Log;
use function PHPUnit\Framework\isEmpty;
use Database\Athletegateway;
use Database\Connexion;

class UserController extends BaseController
{

    private UserManager $userMgr;
    public function __construct(UserManager $manager){
        parent::__construct();
        $this->userMgr =  $manager;
    }

    #[Route(path: '/', name: 'index', methods: ['GET'])]
    public function index(): Response
    {
        return $this->render('./page/index.html',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

    #[Route(path: '/home', name: 'home', methods: ['GET'])]
    public function home(): Response
    {
        $athleteGateway = new AthleteGateway(new Connexion(DSN, DB_USER, DB_PASSWORD));
        $activity = $athleteGateway->getListActivity('1');//$currentUser->getId()

//        $charts = [];
//        $i = 0;
//        while ($i <= 12) {
//            if ($activity[$i]['mois'] == null) {
//                $activity[$i]['mois'] = $i;
//                $activity[$i]['nbactivite'] = 0;
//            } elseif (($indice = intval($activity[$i]['mois'])) != $i) {
//                $temp = $activity[$i]; // Stocker temporairement les données actuelles
//                $activity[$i]['mois'] = $i;
//                $activity[$i]['nbactivite'] = 0;
//                $activity[$indice]['mois'] = $indice;
//                $activity[$indice]['nbactivite'] = $temp['nbactivite']; // Restaurer les données
//            }
//            $charts[] = ['act' => $activity[$i]['nbactivite'], 'mois' => $activity[$i]['mois']];
//            $i++;
//        }

        $charts = [];
        $monthNames = [
            'Janvier', 'Fevrier', 'Mars', 'Avril', 'Mai', 'Juin',
            'Juillet', 'Aout', 'Septembre', 'Octobre', 'Novembre', 'Decembre'
        ];

        $currentDate = new DateTime();
        $interval = new DateInterval('P1M'); // Période d'un mois

        for ($i = 0; $i < 12; $i++) {
            $currentMonth = $currentDate->format('n'); // Format numérique du mois (1 à 12)
            $currentMonthName = $monthNames[$currentMonth - 1]; // Mois correspondant dans le tableau

            // Recherche de l'indice du mois dans le tableau $activity
            $activityIndex = null;
            for ($j = 0; $j < count($activity); $j++) {
                if (!empty($activity[$j]['mois']) && $activity[$j]['mois'] == $currentMonth) {
                    $activityIndex = $j;
                    break;
                }
            }

            // Récupération du nombre d'activités et réinitialisation à 0
            $nbActivity = isset($activityIndex) ? $activity[$activityIndex]['nbactivite'] : 0;
            if (isset($activityIndex)) {
                $activity[$activityIndex]['nbactivite'] = 0;
            }
//            Log::dd($currentMonth);
            $charts[] = ['act' => $nbActivity, 'mois' => $currentMonth];
            $currentDate->sub($interval);
        }

// Inverser l'ordre des éléments si nécessaire
        $charts = array_reverse($charts);

//        Log::dd($charts);

//
//        $charts = [];
//        $monthNames = [
//            'Janvier', 'Février', 'Mars', 'Avril', 'Mai', 'Juin',
//            'Juillet', 'Août', 'Septembre', 'Octobre', 'Novembre', 'Décembre'
//        ];
//
//        $currentDate = new DateTime();
//        $interval = new DateInterval('P1M'); // Période d'un mois
//
//        for ($i = 0; $i < 12; $i++) {
////            $currentDate; // Soustraire un mois
////            Log::dd($currentDate);
//            $currentMonth = $currentDate->format('n'); // Format numérique du mois (1 à 12)
////            Log::dd($currentMonth);
//            $currentMonthName = $monthNames[$currentMonth - 1]; // Mois correspondant dans le tableau
//            for($j = 12; $j > 0; $j--) {
//                if(!empty($activity[$j]['mois']) || $activity[$j]['mois'] == $currentMonth) {
//                    $nbAct = $activity[$j]['nbactivite'];
//                    $activity[$j]['nbactivite'] = 0;
////                    Log::dd($activity);
//                    break;
//                }
//            }
//
//            $nbActivity = isset($nbAct) ? $nbAct : 0;
////            Log::dd($nbActivity);
//
//            $charts[] = ['act' => $nbActivity, 'mois' => $currentMonthName];
//            $currentDate->sub($interval);
//        }
//        Log::dd($charts);

// Inverser l'ordre des éléments si nécessaire
//        $charts = array_reverse($charts);
//
//        Log::dd($charts);
        return $this->render('./page/home.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'charts' => $charts,
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }


    #[Route(path: '/settings', name: 'settings', methods: ['GET'])]
    public function settings(IRequest $req): Response
    {
        return $this->render('./page/settings.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

    #[Route(path: '/profile', name: 'profile', methods: ['GET'])]
    public function profile(): Response
    {
        return $this->render('./page/profile.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

    #[Route(path: '/preferences', name: 'preferences', methods: ['POST'])]
    public function preferences(string $theme, IRequest $req): Response
    {
        /*TODO*/

        //  VALIDER LES DONNEES
        $this->preference->majCookie($theme);
       
        return $this->render('./page/settings.html.twig',[
            'css' => $this->preference->getCookie(),
            'pp' => "test2",
            'user' => "Doe",
            'role' => "Athlète",
            'friendship' => [],
            'analyzes' => [],
            'mails' => [],
            'users' => [],
            'infoUser' => [],
            'exos' => [],
            'member' => []
        ]);
    }

//    #[Route(path: '/logout', name: 'logout', methods: ['GET'])]
//    public function logout(IRequest $request): IResponse
//    {
//        $error = [];
//
//        try {
//
//            if($this->userMgr->deconnecter()){
//                return new RedirectResponse('/');
//            }
//            else{
//                $error [] = "Erreur de deconnexion. Essayez encore";
//                return new RedirectResponse('/');
//            }
//
//        } catch (\Throwable $th) {
//            $error [] =$th->getMessage();
//            return new RedirectResponse('/');
//        }
//    }
    
}