<?php

namespace Database;
use \PDO;
use Shared\Log;

class AthleteGateway {
    private Connexion $connection;

    public function __construct(Connexion $connection) {
        $this->connection = $connection;
    }

    public function getAthlete(): array
    {
        $query = "SELECT * FROM Athlete WHERE isCoach=FALSE";
        $res = $this->connection->executeWithErrorHandling($query);
        return $res;
    }

    public function getAthleteById(int $userId): array
    {
        $query = "SELECT * FROM Athlete WHERE idAthlete = :id AND isCoach=FALSE";
        $params = [':id' => $userId];
//        log::dd($params);
        $res = $this->connection->executeWithErrorHandling($query, $params);
        return $res;
    }

    public function getAthleteByName(string $name): array
    {
        $query = "SELECT * FROM Athlete WHERE nom = :name AND isCoach=FALSE";
        $params = [':name' => $name];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByFirstName(string $firstName): array
    {
        $query = "SELECT * FROM Athlete WHERE prenom = :firstName AND isCoach=FALSE";
        $params = [':firstName' => $firstName];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByEmail(string $email): array
    {
        $query = "SELECT * FROM Athlete WHERE email = :email AND isCoach=FALSE";
        $params = [':email' => $email];
        return $this->connection->executeWithErrorHandling($query, $params);
    }
    public function getUserByEmail(string $email): array
    {
        $query = "SELECT * FROM Athlete WHERE email = :email";
        $params = [':email' => $email];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByGender(string $gender): array
    {
        $query = "SELECT * FROM Athlete WHERE sexe = :gender AND isCoach=FALSE";
        $params = [':gender' => $gender];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByHeight(int $height): array
    {
        $query = "SELECT * FROM Athlete WHERE taille = :height AND isCoach=FALSE";
        $params = [':height' => [$height, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByWeight(int $weight): array
    {
        $query = "SELECT * FROM Athlete WHERE poids = :weight AND isCoach=FALSE";
        $params = [':weight' => [$weight, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getAthleteByBirthDate(string $birthdate): array
    {
        $query = "SELECT * FROM Athlete WHERE dateNaissance = :birthdate AND isCoach=FALSE";
        $params = [':birthdate' => [$birthdate, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getListIdFriends(int $idAthlete): array
    {
        $query = "SELECT idAthlete1, idAthlete2 FROM Friendship WHERE idAthlete1 = :idAthlete OR idAthlete2= :idAthlete";

        $params = [
            ':idAthlete' => $idAthlete,
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getListActivity(int $idAthlete): array
    {
        /*$query = "SELECT count(ac.idActivite) AS nbActivite, EXTRACT(MONTH FROM ac.date) AS mois
              FROM Athlete at, Activite ac
              WHERE at.idAthlete = :idAthlete
                AND ac.date > CURRENT_DATE - INTERVAL '1 YEAR'
                AND ac.athleteId = at.idAthlete
              GROUP BY mois";*/

        $query = "SELECT COUNT(ac.idActivite) AS nbActivite, EXTRACT(MONTH FROM ac.date) AS mois
                FROM Athlete at
                JOIN Activite ac ON ac.athleteId = at.idAthlete
                WHERE at.idAthlete = :idAthlete
                  AND ac.date > CURRENT_DATE - INTERVAL 1 YEAR
                GROUP BY mois";
//        $query = "SELECT count(ac.idActivite) AS nbActivite, EXTRACT(MONTH FROM ac.date) AS mois
//              FROM Athlete at, Activite ac
//              WHERE at.idAthlete = :idAthlete
//                    AND ac.date > CURRENT_DATE - INTERVAL '1 YEAR'
//                    AND ac.athleteId = at.idAthlete
//              GROUP BY mois";

        $params = [
            ':idAthlete' => $idAthlete,
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }


    public function addAthlete(AthleteEntity $athlete): array
    {
        $query = "INSERT INTO Athlete (nom, prenom, email, sexe, taille, poids, motDePasse, dateNaissance, isCoach) 
                  VALUES (:nom, :prenom, :email, :sexe, :taille, :poids, :motDePasse, :dateNaissance, :isCoach)";

        $params = [
            ':nom' => $athlete->getNom(),
            ':prenom' => $athlete->getPrenom(),
            ':email' => $athlete->getEmail(),
            ':sexe' => $athlete->getSexe(),
            ':taille' => $athlete->getTaille(),
            ':poids' => $athlete->getPoids(),
            ':motDePasse' => $athlete->getMotDePasse(),
            ':dateNaissance' => $athlete->getDateNaissance(),
            ':isCoach' => $athlete->getIsCoach(),
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function updateAthlete(AthleteEntity $oldAthlete, AthleteEntity $newAthlete): array
    {
        $query = "UPDATE Athlete 
                  SET username = :username, nom = :nom, prenom = :prenom, email = :email, sexe = :sexe,
                  taille = :taille, poids = :poids, motDePasse = :motDePasse, dateNaissance = :dateNaissance, isCoach = :isCoach
                  WHERE idAthlete = :idAthlete";

        $params = [
            ':idAthlete' => $oldAthlete->getIdAthlete(),
            ':username' => $newAthlete->getUsername(),
            ':nom' => $newAthlete->getNom(),
            ':prenom' => $newAthlete->getPrenom(),
            ':email' => $newAthlete->getEmail(),
            ':sexe' => $newAthlete->getSexe(),
            ':taille' => $newAthlete->getTaille(),
            ':poids' => $newAthlete->getPoids(),
            ':motDePasse' => $newAthlete->getMotDePasse(),
            ':dateNaissance' => $newAthlete->getDateNaissance(),
            ':isCoach' => $newAthlete->getIsCoach(),
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function deleteAthlete(int $idAthlete): array
    {
        $query = "DELETE FROM Athlete WHERE idAthlete = :idAthlete";

        $params = [
            ':idAthlete' => $idAthlete,
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }



}


// Exemple d'utilisation
//$dsn = "pgsql:host=localhost;port=5432;dbname=mydatabase;user=myuser;password=mypassword";
//$connection = new Connection($dsn);
//$gateway = new AthleteGateway($connection);

//$allAth = $gateway->getAthlete();
//print_r($allAth);

//$singleAth = $gateway->getAthleteById(1);
//print_r($singleAth);

?>
