<?php

namespace Database;

class UserGateway
{
    private Connexion $connection;

    public function __construct(Connexion $connection) {
        $this->connection = $connection;
    }

    public function getUsers(): array
    {
        $query = "SELECT * FROM Athlete";
        $res = $this->connection->executeWithErrorHandling($query);
        return $res;
    }

    public function getUserById(int $userId): array
    {
        $query = "SELECT * FROM Athlete WHERE idAthlete = :id";
        $params = [':id' => $userId];
        $res = $this->connection->executeWithErrorHandling($query, $params);
        return $res;
    }

    public function getUserByName(string $name): array
    {
        $query = "SELECT * FROM Athlete WHERE nom = :name";
        $params = [':name' => $name];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getUserByFirstName(string $firstName): array
    {
        $query = "SELECT * FROM Athlete WHERE prenom = :firstName";
        $params = [':firstName' => $firstName];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getUserByEmail(string $email): array
    {
        $query = "SELECT * FROM Athlete WHERE email = :email";
        $params = [':email' => $email];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getUserByGender(string $gender): array
    {
        $query = "SELECT * FROM Athlete WHERE sexe = :gender";
        $params = [':gender' => $gender];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getUserByHeight(int $height): array
    {
        $query = "SELECT * FROM Athlete WHERE taille = :height";
        $params = [':height' => [$height, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getUserByWeight(int $weight): array
    {
        $query = "SELECT * FROM Athlete WHERE poids = :weight";
        $params = [':weight' => [$weight, PDO::PARAM_INT]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function getUserByBirthDate(string $birthdate): array
    {
        $query = "SELECT * FROM Athlete WHERE dateNaissance = :birthdate";
        $params = [':birthdate' => [$birthdate, PDO::PARAM_STR]];
        return $this->connection->executeWithErrorHandling($query, $params);
    }

    public function deleteUserById(int $idAthlete): array
    {
        $query = "DELETE FROM Athlete WHERE idAthlete = :idAthlete";

        $params = [
            ':idAthlete' => $idAthlete,
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }
    public function deleteUserByEmail(string $email): array
    {
        $query = "DELETE FROM Athlete WHERE email = :email";

        $params = [
            ':email' => $email,
        ];

        return $this->connection->executeWithErrorHandling($query, $params);
    }
}