DROP TABLE IF EXISTS Athlete, Friendship, Notification, Statistique, Entrainement, Participe, SourceDonnee, Activite, FrequenceCardiaque CASCADE;

CREATE TABLE Athlete (
                         idAthlete INT AUTO_INCREMENT PRIMARY KEY,
                         username VARCHAR(255),
                         nom VARCHAR(255),
                         prenom VARCHAR(255),
                         email VARCHAR(255) UNIQUE,
                         sexe CHAR(1),
                         taille DECIMAL,
                         poids DECIMAL,
                         motDePasse VARCHAR(255),
                         dateNaissance DATE,
                         isCoach BOOLEAN
);
CREATE TABLE Friendship (
                            idAthlete1 INT,
                            idAthlete2 INT,
                            debut DATE,
                            PRIMARY KEY (idAthlete1, idAthlete2),
                            FOREIGN KEY (idAthlete1) REFERENCES Athlete(idAthlete),
                            FOREIGN KEY (idAthlete2) REFERENCES Athlete(idAthlete)
);

CREATE TABLE Notification (
                              idNotif INT AUTO_INCREMENT PRIMARY KEY,
                              message TEXT,
                              date DATE,
                              statut BOOLEAN,
                              urgence INT,
                              athleteId INT,
                              FOREIGN KEY (athleteId) REFERENCES Athlete(idAthlete)
);

CREATE TABLE Statistique (
                             idStatistique INT AUTO_INCREMENT PRIMARY KEY,
                             poids DECIMAL,
                             fcMoyenne DECIMAL,
                             fcMax DECIMAL,
                             caloriesBruleesMoy DECIMAL,
                             date DATE,
                             athleteId INT,
                             FOREIGN KEY (athleteId) REFERENCES Athlete(idAthlete)
);

CREATE TABLE Entrainement (
                              idEntrainement INT AUTO_INCREMENT PRIMARY KEY,
                              date DATE,
                              description TEXT,
                              latitude DECIMAL,
                              longitude DECIMAL,
                              feedback TEXT,
                              athleteId INT,
                              FOREIGN KEY (athleteId) REFERENCES Athlete(idAthlete)
);

CREATE TABLE Participe (
                           athleteId INT,
                           entrainementId INT,
                           PRIMARY KEY (athleteId, entrainementId),
                           FOREIGN KEY (athleteId) REFERENCES Athlete(idAthlete),
                           FOREIGN KEY (entrainementId) REFERENCES Entrainement(idEntrainement)
);

CREATE TABLE SourceDonnee (
                              idSource INT AUTO_INCREMENT PRIMARY KEY,
                              type VARCHAR(255),
                              modele VARCHAR(255),
                              precision DECIMAL,
                              athleteId INT,
                              FOREIGN KEY (athleteId) REFERENCES Athlete(idAthlete)
);

CREATE TABLE Activite (
                          idActivite INT AUTO_INCREMENT PRIMARY KEY,
                          type VARCHAR(255),
                          date DATE,
                          heureDeDebut TIME,
                          heureDeFin TIME,
                          effortRessent DECIMAL,
                          variabilite DECIMAL,
                          variance DECIMAL,
                          ecartType DECIMAL,
                          moyenne DECIMAL,
                          maximum DECIMAL,
                          minimum DECIMAL,
                          temperatureMoyenne DECIMAL,
                          athleteId INT,
                          sourceId INT,
                          FOREIGN KEY (athleteId) REFERENCES Athlete(idAthlete),
                          FOREIGN KEY (sourceId) REFERENCES SourceDonnee(idSource)
);

CREATE TABLE FrequenceCardiaque (
                                    idFc INT AUTO_INCREMENT PRIMARY KEY,
                                    altitude DECIMAL,
                                    temps TIME,
                                    temperature DECIMAL,
                                    bpm INT,
                                    longitude DECIMAL,
                                    latitude DECIMAL,
                                    activiteId INT,
                                    FOREIGN KEY (activiteId) REFERENCES Activite(idActivite)
);

-- \i athlete.sql
-- \i friendship.sql