<?php
namespace Network;

use App\Router\Session;
use Database\AthleteGateway;
use Database\AthleteMapper;
use Database\CoachMapper;
use Database\Connexion;
use Database\UserGateway;
use Model\User;
use Model\Athlete;
use Model\CoachAthlete;
use Repository\IUserRepository;
use Shared\IHashPassword;
use Shared\Log;
const USER = 'USER';
class AuthService implements IAuthService
{
    private IUserRepository $userRepository;
    private IHashPassword $passwordHacher;

    private ?User $currentUser = null;

    public function __construct(IUserRepository $userRepository, IHashPassword $passwordHacher)
    {
        $this->userRepository = $userRepository;
        $this->passwordHacher = $passwordHacher;
    }

    public function login(string $email, string $password): bool
    {
//        $user = $this->userRepository->getItemByEmail($email);
        $userGateway = new UserGateway(new Connexion(DSN, DB_USER, DB_PASSWORD));
        $userRepository = $userGateway->getUserByEmail($email);
//        Log::dd($userRepository[0]['isCoach']);
        if($userRepository[0]['isCoach']) {
            $map = new CoachMapper();
            $coachEntity = $map->coachSqlToEntity($userRepository);
//            $user = [];
            foreach($coachEntity as $coachs) {
                $user = $map->CoachEntityToModel($coachs);
            }
        } else {
            $map = new AthleteMapper();
            $athleteEntity = $map->athleteSqlToEntity($userRepository);
            foreach($athleteEntity as $coachs) {
                $user = $map->AthleteEntityToModel($coachs);
            }
        }

//        Log::dd($user);
//        $map->athleteEntityToModel($userRepository)

//        $user = ['username' => $userEntity[0]->getUsername(), 'nom' => $userEntity[0]->getNom(),
//            'prenom' => $userEntity[0]->getPrenom(),'email' => $userEntity[0]->getEmail(), 'sexe' => $userEntity[0]->getSexe(),
//            'taille' => $userEntity[0]->getTaille(), 'poids' => $userEntity[0]->getPoids(), 'motdepasse' => $userEntity[0]->getMotDePasse(),
//            'datenaissance' => $userEntity[0]->getDateNaissance(), 'iscoach' => $userEntity[0]->getIsCoach(), 'img' => 'test'];
//        Log::dd($this->passwordHacher->isPasswordValid($user->getMotDePasse(),$password));
        if ($user === null || !$this->passwordHacher->isPasswordValid($user->getMotDePasse(),$password)) {
            return false;
        }
        $this->currentUser = $user;
//        Log::dd(Session::getInstance()->__get(USER));
        Session::getInstance()->__set(USER, $this->currentUser->getId());
//        Log::dd(Session::getInstance()->__set(USER, $this->currentUser->getId()));
        return true;
    }



    public function register(string $email, string $password, $data): bool
    {
        if ($this->userRepository->getItemByEmail($email)) {
            throw new \Exception('User already exists');
        }

        $hashedPassword = $this->passwordHacher->hashPassword($password);
        $prenom = $data['prenom'];
        $username = $data['username'];
        $nom = $data['nom'];
        $sexe = $data['sexe'];
        $taille = $data['taille'];
        $poids = $data['poids'];
        $dateNaissance = $data['dateNaissance'];
        $roleName = $data['roleName'];
        $role = null;
        if ($roleName == "Coach") {
            $role = new CoachAthlete();
        } else if ($roleName == "Athlete") {
            $role = new Athlete();
        }

        $user = new User(
            $nom,
            $prenom,
            $username,
            $email,
            $hashedPassword,
            $sexe,
            $taille,
            $poids,
            $dateNaissance,
            $role
        );
        $this->userRepository->addItem($user);
        $this->currentUser = $user;
        Session::getInstance()->__set(USER,$this->currentUser->getId());


        return true;
    }

    public function logoutUser(): bool
    {
        $this->currentUser = null;
        Session::getInstance()->destroy();
        return true;
    }
    
    public function getCurrentUser(): ?User
    {
        if (!empty(Session::getInstance()->__get(USER)) && $this->currentUser === null) {
            $this->currentUser = $this->userRepository->getItemById(Session::getInstance()->__get(USER));
        }
        return $this->currentUser;
    }


}
